==> nextcloud-23.0.12p0.tgz: nextcloud/apps/workflowengine/l10n/el.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Ο δοσμένος πάροχος δεν είναι έγκυρος",
    "The given regular expression is invalid" : "Η δοθείσα κανονική έκφραση δεν είναι έγκυρη",
    "The given file size is invalid" : "Το δοσμένο μέγεθος αρχείου δεν είναι έγκυρο",
    "The given tag id is invalid" : "Το δοσμένο id της ετικέτας δεν είναι έγκυρο",
    "The given IP range is invalid" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη",
    "The given IP range is not valid for IPv4" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη για IPv4",
    "The given IP range is not valid for IPv6" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη για IPv6",
    "The given time span is invalid" : "Το δοσμένο χρονικό περιθώριο δεν είναι έγκυρο",
    "The given start time is invalid" : "Ο δοσμένος χρόνος έναρξης δεν είναι έγκυρος",
    "The given end time is invalid" : "Ο δοσμένος χρόνος λήξης δεν είναι έγκυρος",
    "The given group does not exist" : "Η δοσμένη ομάδα δεν υπάρχει",
    "File" : "Αρχείο",
    "File created" : "Το αρχείο δημιουργήθηκε",
    "File updated" : "Το αρχείο ενημερώθηκε",
    "File renamed" : "Το αρχείο μετονομάστηκε",
    "File deleted" : "Το αρχείο διαγράφηκε",
    "File accessed" : "Προσβάσιμο αρχείο",
    "File copied" : "Το αρχείο αντιγράφηκε",
    "Tag assigned" : "Ορίστηκε ετικέτα",
    "Someone" : "Κάποιος",
    "%s created %s" : "%s δημιουργήθηκε %s",
    "%s modified %s" : "%s τροποποιήθηκε %s",
    "%s deleted %s" : "%s διαγράφηκε %s",
    "%s accessed %s" : "%s πρόσβαση %s",
    "%s renamed %s" : "%s μετονομάστηκε%s",
    "%s copied %s" : "%s αντιγράφηκε%s",
    "%s assigned %s to %s" : "%s ορίστηκε %s σε %s",
    "Operation #%s does not exist" : "Λειτουργία #%s δεν υπάρχει",
    "Entity %s does not exist" : "Η οντότητα %s δεν υπάρχει",
    "Entity %s is invalid" : "Η οντότητα %s δεν είναι έγκυρη",
    "No events are chosen." : "Κανένα γεγονός δεν επιλέχθηκε.",
    "Entity %s has no event %s" : "Η οντότητα %s δεν έχει γεγονότα %s",
    "Operation %s does not exist" : "Λειτουργία %s δεν υπάρχει",
    "Operation %s is invalid" : "Λειτουργία %s δεν είναι έγκυρη",
    "At least one check needs to be provided" : "Χρειάζεται τουλάχιστο μία επιλογή",
    "The provided operation data is too long" : "Τα παρεχόμενα δεδομένα λειτουργίας είναι πολύ μεγάλα",
    "Invalid check provided" : "Έχει δοθεί λάθος επιλογή",
    "Check %s does not exist" : "Έλεγχος %s δεν υπάρχει",
    "Check %s is invalid" : "Έλεγχος %s δεν είναι έγκυρος",
    "Check %s is not allowed with this entity" : "Η επιλογή %s δεν επιτρέπετε για αυτή την οντότητα",
    "The provided check value is too long" : "Η παρεχόμενη τιμή ελέγχου είναι πολύ μεγάλη",
    "Check #%s does not exist" : "Έλεγχος #%s δεν υπάρχει",
    "Check %s is invalid or does not exist" : "Έλεγχος %s δεν είναι έγκυρος ή δεν υπάρχει",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Σύστημα ροής εργασιών Nextcloud",
    "Select a filter" : "Επιλογή φίλτρου",
    "Select a comparator" : "Επιλέξτε για σύγκριση",
    "Select a file type" : "Επιλέξτε τύπο αρχείου",
    "e.g. httpd/unix-directory" : "π.χ. httpd/unix-directory",
    "Folder" : "Φάκελος",
    "Images" : "Εικόνες",
    "Office documents" : "Έγγραφα γραφείου",
    "PDF documents" : "Έγγραφα PDF",
    "Custom MIME type" : "Προσαρμοσμένος τύπος MIME",
    "Custom mimetype" : "Προσαρμοσμένος τύπος mime",
    "Please enter a valid time span" : "Εισαγάγετε έγκυρο χρονικό διάστημα",
    "Select a request URL" : "Επιλέξτε μια διεύθυνση URL αιτήματος",
    "Predefined URLs" : "Προορισμένα URLs",
    "Files WebDAV" : "Αρχεία WebDAV",
    "Others" : "Άλλοι",
    "Custom URL" : "Προσαρμοσμένο URL",
    "Select a user agent" : "Επιλογή προγράμματος χρήστη",
    "Android client" : "Πελάτης Android",
    "iOS client" : "Πελάτης iOS",
    "Desktop client" : "Πελάτης σταθερού υπολογιστή",
    "Thunderbird & Outlook addons" : "Πρόσθετα των Thunderbird & Outlook",
    "Custom user agent" : "Προσαρμοσμένο πρόγραμμα χρήστη",
    "At least one event must be selected" : "Τουλάχιστον ένα γεγονός πρέπει να επιλεγεί",
    "Add new flow" : "Προσθήκη νέας ροής",
    "When" : "Πότε",
    "and" : "και",
    "Cancel" : "Ακύρωση",
    "Delete" : "Διαγραφή",
    "The configuration is invalid" : "Μή έγκυρη ρύθμιση",
    "Active" : "Ενεργό",
    "Save" : "Αποθήκευση",
    "Available flows" : "Διαθέσιμες ροές",
    "For details on how to write your own flow, check out the development documentation." : "Για λεπτομέρεις πως μπορείτε να συντάξετε δική σας ροή, δείτε στην τεκμηρίωση προγραμματιστών.",
    "More flows" : "Περισσότερες ροές",
    "Browse the App Store" : "Εξερευνήστε την Αγορά εφαρμογών",
    "Show less" : "Εμφάνιση λιγότερων",
    "Show more" : "Εμφάνιση περισσότερων",
    "Configured flows" : "Ρύθμιση ροών",
    "Your flows" : "Οι ροές σας",
    "matches" : "ταιριάζει",
    "does not match" : "δεν ταιριάζει",
    "is" : "είναι",
    "is not" : "δεν είναι",
    "File name" : "Όνομα αρχείου",
    "File MIME type" : "Τύπος αρχείου MIME",
    "File size (upload)" : "Μέγεθος αρχείου (μεταφόρτωση)",
    "less" : "Λιγότερα",
    "less or equals" : "Λιγότερο ή ίσον",
    "greater or equals" : "είναι μεγαλύτερο ή ίσο",
    "greater" : "μεγαλύτερος",
    "Request remote address" : "Αιτηθείτε απομακρυσμένη διέυθυνση",
    "matches IPv4" : "ταιριάζει IPv4",
    "does not match IPv4" : "δεν ταιριάζει IPv4",
    "matches IPv6" : "ταιριάζει με IPv6",
    "does not match IPv6" : "δεν ταιριάζει με IPv6",
    "File system tag" : "Ετικέτα συστήματος αρχείου",
    "is tagged with" : "έχει σημειωθεί με",
    "is not tagged with" : "δεν έχει σημειωθεί με",
    "Request URL" : "Αιτηθείτε URL",
    "Request time" : "Αιτηθείτε χρόνο",
    "between" : "μεταξύ",
    "not between" : "όχι μεταξύ",
    "Request user agent" : "Αιτηθείτε αντιπρόσωπο χρήστη",
    "User group membership" : "Συμμετοχή σε ομάδα χρηστών",
    "is member of" : "είναι μέλος του",
    "is not member of" : "δεν είναι μέλος του",
    "Select a tag" : "Επιλογή ετικέτας",
    "No results" : "Κανένα αποτέλεσμα",
    "%s (invisible)" : "%s (αόρατο)",
    "%s (restricted)" : "%s (περιορισμένο)"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.5.tgz: nextcloud/apps/workflowengine/l10n/el.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Ο δοσμένος πάροχος δεν είναι έγκυρος",
    "The given regular expression is invalid" : "Η δοθείσα κανονική έκφραση δεν είναι έγκυρη",
    "The given file size is invalid" : "Το δοσμένο μέγεθος αρχείου δεν είναι έγκυρο",
    "The given tag id is invalid" : "Το δοσμένο id της ετικέτας δεν είναι έγκυρο",
    "The given IP range is invalid" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη",
    "The given IP range is not valid for IPv4" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη για IPv4",
    "The given IP range is not valid for IPv6" : "Η δοσμένη περιοχή IP δεν είναι έγκυρη για IPv6",
    "The given time span is invalid" : "Το δοσμένο χρονικό περιθώριο δεν είναι έγκυρο",
    "The given start time is invalid" : "Ο δοσμένος χρόνος έναρξης δεν είναι έγκυρος",
    "The given end time is invalid" : "Ο δοσμένος χρόνος λήξης δεν είναι έγκυρος",
    "The given group does not exist" : "Η δοσμένη ομάδα δεν υπάρχει",
    "File" : "Αρχείο",
    "File created" : "Το αρχείο δημιουργήθηκε",
    "File updated" : "Το αρχείο ενημερώθηκε",
    "File renamed" : "Το αρχείο μετονομάστηκε",
    "File deleted" : "Το αρχείο διαγράφηκε",
    "File accessed" : "Προσβάσιμο αρχείο",
    "File copied" : "Το αρχείο αντιγράφηκε",
    "Tag assigned" : "Ορίστηκε ετικέτα",
    "Someone" : "Κάποιος",
    "%s created %s" : "%s δημιουργήθηκε %s",
    "%s modified %s" : "%s τροποποιήθηκε %s",
    "%s deleted %s" : "%s διαγράφηκε %s",
    "%s accessed %s" : "%s πρόσβαση %s",
    "%s renamed %s" : "%s μετονομάστηκε%s",
    "%s copied %s" : "%s αντιγράφηκε%s",
    "%s assigned %s to %s" : "%s ορίστηκε %s σε %s",
    "Operation #%s does not exist" : "Λειτουργία #%s δεν υπάρχει",
    "Entity %s does not exist" : "Η οντότητα %s δεν υπάρχει",
    "Entity %s is invalid" : "Η οντότητα %s δεν είναι έγκυρη",
    "No events are chosen." : "Κανένα γεγονός δεν επιλέχθηκε.",
    "Entity %s has no event %s" : "Η οντότητα %s δεν έχει γεγονότα %s",
    "Operation %s does not exist" : "Λειτουργία %s δεν υπάρχει",
    "Operation %s is invalid" : "Λειτουργία %s δεν είναι έγκυρη",
    "At least one check needs to be provided" : "Χρειάζεται τουλάχιστο μία επιλογή",
    "The provided operation data is too long" : "Τα παρεχόμενα δεδομένα λειτουργίας είναι πολύ μεγάλα",
    "Invalid check provided" : "Έχει δοθεί λάθος επιλογή",
    "Check %s does not exist" : "Έλεγχος %s δεν υπάρχει",
    "Check %s is invalid" : "Έλεγχος %s δεν είναι έγκυρος",
    "Check %s is not allowed with this entity" : "Η επιλογή %s δεν επιτρέπεται για αυτή την οντότητα",
    "The provided check value is too long" : "Η παρεχόμενη τιμή ελέγχου είναι πολύ μεγάλη",
    "Check #%s does not exist" : "Έλεγχος #%s δεν υπάρχει",
    "Check %s is invalid or does not exist" : "Έλεγχος %s δεν είναι έγκυρος ή δεν υπάρχει",
    "Flow" : "Flow",
    "Nextcloud workflow engine" : "Σύστημα ροής εργασιών Nextcloud",
    "Select a filter" : "Επιλογή φίλτρου",
    "Select a comparator" : "Επιλέξτε για σύγκριση",
    "Select a file type" : "Επιλέξτε τύπο αρχείου",
    "e.g. httpd/unix-directory" : "π.χ. httpd/unix-directory",
    "Folder" : "Φάκελος",
    "Images" : "Εικόνες",
    "Office documents" : "Έγγραφα γραφείου",
    "PDF documents" : "Έγγραφα PDF",
    "Custom MIME type" : "Προσαρμοσμένος τύπος MIME",
    "Custom mimetype" : "Προσαρμοσμένος τύπος mime",
    "Please enter a valid time span" : "Εισαγάγετε έγκυρο χρονικό διάστημα",
    "Select a request URL" : "Επιλέξτε μια διεύθυνση URL αιτήματος",
    "Predefined URLs" : "Προορισμένα URLs",
    "Files WebDAV" : "Αρχεία WebDAV",
    "Others" : "Άλλοι",
    "Custom URL" : "Προσαρμοσμένο URL",
    "Select a user agent" : "Επιλογή προγράμματος χρήστη",
    "Android client" : "Πελάτης Android",
    "iOS client" : "Πελάτης iOS",
    "Desktop client" : "Πελάτης σταθερού υπολογιστή",
    "Thunderbird & Outlook addons" : "Πρόσθετα των Thunderbird & Outlook",
    "Custom user agent" : "Προσαρμοσμένο πρόγραμμα χρήστη",
    "At least one event must be selected" : "Τουλάχιστον ένα γεγονός πρέπει να επιλεγεί",
    "Add new flow" : "Προσθήκη νέας ροής",
    "When" : "Πότε",
    "and" : "και",
    "Cancel" : "Ακύρωση",
    "Delete" : "Διαγραφή",
    "The configuration is invalid" : "Μή έγκυρη ρύθμιση",
    "Active" : "Ενεργό",
    "Save" : "Αποθήκευση",
    "Available flows" : "Διαθέσιμες ροές",
    "For details on how to write your own flow, check out the development documentation." : "Για λεπτομέρεις πως μπορείτε να συντάξετε δική σας ροή, δείτε στην τεκμηρίωση προγραμματιστών.",
    "More flows" : "Περισσότερες ροές",
    "Browse the App Store" : "Εξερευνήστε την Αγορά εφαρμογών",
    "Show less" : "Εμφάνιση λιγότερων",
    "Show more" : "Εμφάνιση περισσότερων",
    "Configured flows" : "Ρύθμιση ροών",
    "Your flows" : "Οι ροές σας",
    "matches" : "ταιριάζει",
    "does not match" : "δεν ταιριάζει",
    "is" : "είναι",
    "is not" : "δεν είναι",
    "File name" : "Όνομα αρχείου",
    "File MIME type" : "Τύπος αρχείου MIME",
    "File size (upload)" : "Μέγεθος αρχείου (μεταφόρτωση)",
    "less" : "Λιγότερα",
    "less or equals" : "Λιγότερο ή ίσον",
    "greater or equals" : "είναι μεγαλύτερο ή ίσο",
    "greater" : "μεγαλύτερος",
    "Request remote address" : "Αιτηθείτε απομακρυσμένη διέυθυνση",
    "matches IPv4" : "ταιριάζει IPv4",
    "does not match IPv4" : "δεν ταιριάζει IPv4",
    "matches IPv6" : "ταιριάζει με IPv6",
    "does not match IPv6" : "δεν ταιριάζει με IPv6",
    "File system tag" : "Ετικέτα συστήματος αρχείου",
    "is tagged with" : "έχει σημειωθεί με",
    "is not tagged with" : "δεν έχει σημειωθεί με",
    "Request URL" : "Αιτηθείτε URL",
    "Request time" : "Αιτηθείτε χρόνο",
    "between" : "μεταξύ",
    "not between" : "όχι μεταξύ",
    "Request user agent" : "Αιτηθείτε αντιπρόσωπο χρήστη",
    "User group membership" : "Συμμετοχή σε ομάδα χρηστών",
    "is member of" : "είναι μέλος του",
    "is not member of" : "δεν είναι μέλος του",
    "Select a tag" : "Επιλογή ετικέτας",
    "No results" : "Κανένα αποτέλεσμα",
    "%s (invisible)" : "%s (αόρατο)",
    "%s (restricted)" : "%s (περιορισμένο)"
},
"nplurals=2; plural=(n != 1);");
